pub fn format_failure_line(reason: &str) -> StringExpand description
Builds the one line a shell logs when the devtools service fails to start.
The shell side’s only formatter — pair of parse_failure_line.
pub fn format_failure_line(reason: &str) -> StringBuilds the one line a shell logs when the devtools service fails to start.
The shell side’s only formatter — pair of parse_failure_line.